Index: wp-admin/includes/taxonomy.php
===================================================================
--- wp-admin/includes/taxonomy.php	(revision 15675)
+++ wp-admin/includes/taxonomy.php	(working copy)
@@ -80,25 +80,6 @@
 }
 
 /**
- * Deletes one existing category.
- *
- * @since 2.0.0
- *
- * @param int $cat_ID
- * @return mixed Returns true if completes delete action; false if term doesnt exist; Zero on attempted deletion of default Category; WP_Error object is also a possibility.
- */
-function wp_delete_category($cat_ID) {
-	$cat_ID = (int) $cat_ID;
-	$default = get_option('default_category');
-
-	// Don't delete the default cat
-	if ( $cat_ID == $default )
-		return 0;
-
-	return wp_delete_term($cat_ID, 'category', array('default' => $default));
-}
-
-/**
  * Updates an existing Category or creates a new Category.
  *
  * @since 2.0.0
Index: wp-admin/includes/deprecated.php
===================================================================
--- wp-admin/includes/deprecated.php	(revision 15675)
+++ wp-admin/includes/deprecated.php	(working copy)
@@ -55,6 +55,21 @@
 }
 
 /**
+ * Deletes one existing category.
+ *
+ * @since 2.0.0
+ * @deprecated 3.1
+ * @deprecated use wp_delete_term()
+ *
+ * @param int $cat_ID
+ * @return mixed Returns true if completes delete action; false if term doesnt exist; Zero on attempted deletion of default Category; WP_Error object is also a possibility.
+ */
+function wp_delete_category($cat_ID) {
+	_deprecated_function( __FUNCTION__, '3.1', 'wp_delete_term()' );
+	return wp_delete_term( $cat_ID );
+}
+
+/**
  * {@internal Missing Short Description}}
  *
  * @since unknown
Index: wp-includes/taxonomy.php
===================================================================
--- wp-includes/taxonomy.php	(revision 15675)
+++ wp-includes/taxonomy.php	(working copy)
@@ -1455,10 +1455,17 @@
 	$tt_id = $ids['term_taxonomy_id'];
 
 	$defaults = array();
+	
+	if ( 'category' == $taxonomy ) {
+		$defaults['default'] = get_option( 'default_category' );
+		if ( $defaults['default'] == $term )
+			return 0; // Don't delete the default category
+	}
+	
 	$args = wp_parse_args($args, $defaults);
 	extract($args, EXTR_SKIP);
 
-	if ( isset($default) ) {
+	if ( isset( $default ) ) {
 		$default = (int) $default;
 		if ( ! term_exists($default, $taxonomy) )
 			unset($default);
Index: wp-includes/class.wp-xmlrpc-server.php
===================================================================
--- wp-includes/class.wp-xmlrpc-server.php	(revision 15675)
+++ wp-includes/class.wp-xmlrpc-server.php	(working copy)
@@ -859,7 +859,7 @@
 	 * @since 2.5.0
 	 *
 	 * @param array $args Method parameters.
 	 * @return mixed See {@link wp_delete_category()} for return info.
 	 */
 	function wp_deleteCategory($args) {
 		$this->escape($args);
@@ -877,7 +877,7 @@
 		if ( !current_user_can("manage_categories") )
 			return new IXR_Error( 401, __( "Sorry, you do not have the right to delete a category." ) );
 
-		return wp_delete_category( $category_id );
+		return wp_delete_term( $category_id, 'category' );
 	}
 
 	/**
@@ -859,7 +859,7 @@
 	 *
 	 * @param array $args Method parameters.
-	 * @return mixed See {@link wp_delete_category()} for return info.
+	 * @return mixed See {@link wp_delete_term()} for return info.
 	 */
 	function wp_deleteCategory($args) {
